@@ -17,7 +17,7 @@ die( "Usage: $0 <input_text_file> <output_audio_file> <voice>\n" )
 my ( $textfilename, $audiofilename, $voice ) = @ARGV;
 
 # Run balabolka, run!
-my $command = [ "balabloka.exe",
+my $command = [ "balabolka.exe",
 		"-mqs",
 		$textfilename,
 		$audiofilename,
@@ -38,7 +38,7 @@ balabolka.pl - script converting textfile named $1
 
 =head1 VERSION
 
-version 20240619.1728
+version 20240619.1846
 
 =head1 AUTHOR
 
